@@ -9,12 +9,15 @@ from centralized_pre_commit_conf.parse_args import parse_args
 from centralized_pre_commit_conf.prints import error, info
 
 
-def run():
+def run() -> None:
     config = confuse.Configuration(APPLICATION_NAME, __name__)
     try:
         config = parse_args(config)
     except confuse.ConfigError as e:
-        error(f"Problem with your configuration file in {[s.filename for s in config.sources]}: {e}")
+        error(
+            "Problem with your configuration file in "
+            f"{[s.filename for s in config.sources]}: {e}"
+        )
         sys.exit(ExitCode.PRE_COMMIT_CONF_NOT_FOUND.value)
     config_path = Path(config.config_dir()).resolve() / "config.yaml"
     if not config_path.exists():
