@@ -1,19 +1,21 @@
+from typing import Union
+
 from colorama import Fore, init
 
 init()
 
 
-def info(message):
+def info(message: str) -> None:
     print(f"{Fore.BLUE}{message}{Fore.RESET}")
 
 
-def warn(message):
+def warn(message: Union[Warning, str]) -> None:
     print(f"{Fore.YELLOW}{message}{Fore.RESET}")
 
 
-def error(message):
+def error(message: str) -> None:
     print(f"{Fore.RED}{message}{Fore.RESET}")
 
 
-def success(message):
+def success(message: str) -> None:
     print(f"{Fore.GREEN}{message}{Fore.RESET}")
